@@ -3,9 +3,12 @@ package Repository::Simple::Engine;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Readonly;
+use Repository::Simple::Util;
+
+our @CARP_NOT = qw( Repository::Simple::Util );
 
 require Exporter;
 
